@@ -1,6 +1,6 @@
 #' EM Algorithm for Fitting Regression Models to Group Testing Data
 #'
-#' This function implements an expectation-maximization (EM) algorithm to fit regression models to group testing data, where pooled responses are related to individual covariates through a link function in the generalized linear model (GLM) family. The EM algorithm finds the maximum likelihood estimate (MLE) for the vector of regression coefficients, \strong{beta}. The EM algorithm can model pooling data observed from \strong{any} group testing protocol used in practice, including hierarchical and array testing (Kim et al., 2007).
+#' This function implements an expectation-maximization (EM) algorithm to fit regression models to group testing data, where pooled responses are related to individual covariates through a link function in the generalized linear model (GLM) family. The EM algorithm, which is outlined in Warasi (2021), finds the maximum likelihood estimate (MLE) for the vector of regression coefficients, \strong{beta}. The EM algorithm can model pooling data observed from \strong{any} group testing protocol used in practice, including hierarchical and array testing (Kim et al., 2007).
 #'
 #' @useDynLib groupTesting, .registration=TRUE
 #'
@@ -72,12 +72,15 @@
 #' 
 #' Vansteelandt S, Goetghebeur E, and Verstraeten T. (2000). Regression Models for Disease Prevalence with Diagnostic Tests on Pools of Serum Samples. \emph{Biometrics}, 56:1126-1133. 
 #' 
+#' Warasi M. (2021). groupTesting: An R Package for Group Testing Estimation. \emph{Communications in Statistics-Simulation and Computation}. Published online on Dec 9, 2021.
+#' Available at https://www.tandfonline.com/doi/full/10.1080/03610918.2021.2009867
+#' 
 #' @seealso
 #' \code{\link{hier.gt.simulation}} and \code{\link{array.gt.simulation}} for group testing data simulation, and \code{\link{prop.gt}} for estimation of a disease prevalence from group testing data.
 #'
 #' @examples
 #'
-#' library("groupTesting")
+#' library(groupTesting)
 #' 
 #' ## To illustrate 'glm.gt', we use data simulated  
 #' ## by the functions 'hier.gt.simulation' and 'array.gt.simulation'.
@@ -344,7 +347,7 @@ glm.gt <- function(beta0,gtData,X,g,dg=NULL,d2g=NULL,grdMethod=c("central","forw
   ## The EM algorithm starts here  
   while(max(abs(param1-param0)) > tol){  # Start iterating
     param0 <- param1
-	pvec <- apply(X%*%param0, 2, g)
+	  pvec <- apply(X%*%param0, 2, g)
     U <- matrix(stats::runif(N*GI),nrow=N,ncol=GI)
 
     ## Gibbs sampling in Fortran to approximate the E-step
@@ -364,7 +367,7 @@ glm.gt <- function(beta0,gtData,X,g,dg=NULL,d2g=NULL,grdMethod=c("central","forw
     }
     s <- s + 1
     if(tracing){
-      print(c(s-1,param1))
+      cat(s-1, param1, "\n")
     }
   }
 
